/*
 * Copyright (c) 2009 CTTC
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2 as
 * published by the Free Software Foundation;
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Author: Nicola Baldo <nbaldo@cttc.es>
 */

#ifndef FREQS_ISM2400MHZ_RES1MHZ_H
#define FREQS_ISM2400MHZ_RES1MHZ_H

#include "spectrum-value.h"

namespace ns3
{

extern Ptr<SpectrumModel> SpectrumModelIsm2400MhzRes1Mhz;

}

#endif /* FREQS_ISM2400MHZ_RES1MHZ_H */
